#include "install.h"
#include <stdio.h>
#include <QTextStream>
#include <QProcess>

Install::Install()
{
}


QString Install::getenv(QString var)
{
	QStringList environment = QProcess::systemEnvironment();
	for(int i=0;i<environment.size();i++)
	{
		if( environment[i].startsWith(var+"=") )
		{
			QString str(environment[i]);
			str.remove(0,var.length()+1);
			return str;
		}
	}
	return QString();
}

void Install::build_scripts()
{

	FILE *out=fopen("Makefile","w");
	if(out==NULL)
	{
		printf("Error: Makefile couldn't be written in disk.\n");
		return;
	}
	
	QString make=getenv("MAKETOOL");
			
	QString makefile;
	
	QTextStream sout(&makefile);
	
	sout << "all:\n";
	sout << "\tcd qtoctave; " << qmake << "\n";
	sout << "\tcd qtoctave; " << make << "\n";
	sout << "\tcd widgetserver; " << qmake << "\n";
	sout << "\tcd widgetserver; " << make << "\n";
	
	sout << "install:\n";
	sout << "\tcd qtoctave; " << make << " install\n";
	sout << "\tcd widgetserver; " << make << " install\n";
	
	sout << "uninstall:\n";
	sout << "\tcd qtoctave; " << make << " uninstall\n";
	sout << "\tcd widgetserver; " << make << " uninstall\n";
	
	sout << "clean:\n";
	sout << "\tcd qtoctave; " << make << " clean\n";
	sout << "\tcd widgetserver; " << make << " clean\n";
	sout << "\tcd install-tool; " << make << " clean\n";
	
	fprintf(out,makefile.toLocal8Bit().data());
	
	fclose(out);
	
	system( ("cd qtoctave; " + qmake + " -project; cd ..").toLocal8Bit().data() );
	system( ("cd widgetserver; " + qmake + " -project; cd ..").toLocal8Bit().data() );
	
	out=fopen("qtoctave/qtoctave.pro","a");
	if(out==NULL)
	{
		printf("Error: qtoctave.pro couldn't be written in disk.\n");
		return;
	}
	
	QString qmakefile;
	QTextStream qout(&qmakefile);
	
	
	if( help_path.isEmpty() )
	{
		qout << "octave_help.path = " << install_path << "/octave_doc/\n";
		qout << "octave_help.files = ./octave_doc/*\n";
		qout << "INSTALLS+=octave_help\n";
	}
	
	qout << "DEFINES+=USER_CONFIG\n";
	qout << "QT+=xml\n";
	
	qout << "qtoctave_help.path = " << install_path << "/qtoctave_doc/\n";
	qout << "qtoctave_help.files = ./qtoctave_doc/*\n";
	qout << "INSTALLS+=qtoctave_help\n";
	
	qout << "octave_help.path = " << install_path << "/octave_doc/\n";
	qout << "octave_help.files = ./octave_doc/*\n";
	qout << "INSTALLS+=octave_help\n";
	
	qout << "images.path = " << install_path << "/images/\n";
	qout << "images.files = ./images/*\n";
	qout << "INSTALLS+=images\n";
	
	qout << "menus.path = " << install_path << "/menus/\n";
	qout << "menus.files = ./menus/*\n";
	qout << "INSTALLS+=menus\n";
	
	qout << "configrc.path = " << install_path << "\n";
	qout << "configrc.files = config.rc\n";
	qout << "INSTALLS+=configrc\n";

	qout << "editor.path = " << install_path << "\n";
	qout << "editor.files = octave.xml autocomplete.lst\n";
	qout << "INSTALLS+=editor\n";
	
	qout << "target.path = " << bin_path << "\n";
	qout << "INSTALLS+=target\n";
	
	
	fprintf(out,qmakefile.toLocal8Bit().data());
	
	fclose(out);
	
	
	out=fopen("widgetserver/widgetserver.pro","a");
	if(out==NULL)
	{
		printf("Error: widgetserver.pro couldn't be written in disk.\n");
		return;
	}
	
	QString wmakefile;
	QTextStream wout(&wmakefile);
	
	wout << "target.path = " << bin_path << "\n";
	wout << "INSTALLS+=target\n";
	
	fprintf(out,wmakefile.toLocal8Bit().data());
	
	fclose(out);
	
	out=fopen("qtoctave/configure.h","w");
	if(out==NULL)
	{
		printf("Error: qtoctave/configure.h couldn't be written in disk.\n");
		return;
	}
	
	QString configureh;
	QTextStream coout(&configureh);
	
	if( ! install_path.isEmpty() )
	{
		coout << "#define CONFIG_PATH \"" << install_path << "\"\n";
		coout << "#define ICON_PATH \"" << install_path << "/images\"\n";
		coout << "#define QTOCTAVE_HELP_PATH \"" << install_path << "/qtoctave_doc/index.html\"\n";
	}
	if( help_path.isEmpty() )
	{
		coout << "#define HELP_PATH \"" << help_path << "\"\n";
	}
	else
	{
		coout << "#define HELP_PATH \"" << install_path << "/octave_doc/octave.html\"" << "\n";
	}
	
	coout << "\n";
	
	fprintf(out,configureh.toLocal8Bit().data());
	
	fclose(out);
}

void Install::compile_pushButton_cb()
{
	build_scripts();
	QString make=getenv("MAKETOOL");
	system( make.toLocal8Bit().data() );
	printf("\nCompilation ended\n");
}

void Install::compile_install_pushButton_cb()
{
	build_scripts();
	QString make=getenv("MAKETOOL");
	system( make.toLocal8Bit().data() );
	system( (make+" install").toLocal8Bit().data() );
	printf("\nInstall ended\n");
}

